summaryrefslogtreecommitdiff
path: root/kernel/con.c
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/con.c')
-rw-r--r--kernel/con.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kernel/con.c b/kernel/con.c
index 69c34e1..c8be80b 100644
--- a/kernel/con.c
+++ b/kernel/con.c
@@ -1,13 +1,13 @@
/*
* con.c
*
* Basic VGA text console. Implements printf() and puts().
*/
#include <asm/io.h>
-#include <kernel/vsprintf.h>
#include <stdarg.h>
#include <stdint.h>
+#include <stdio.h>
#define COLS 80
#define ROWS 25
@@ -64,7 +64,7 @@ void con_init(void) {
}
/* write a zero-terminated string to console */
-int puts(char *s) {
+static int puts(char *s) {
uint8_t *p = &vram[pos];
while(*s) {
@@ -91,7 +91,7 @@ int puts(char *s) {
return 0;
}
-int printf(char *fmt, ...) {
+int printk(char *fmt, ...) {
int ret;
char buf[1024];
va_list ap;
@@ -1,13 +1,13 @@
* con.c
*
- * Basic VGA text console. Implements printf() and puts().
+ * Basic VGA text console. Implements printk() and puts().
*/
#include <asm/io.h>